@@ -68,21 +68,18 @@ def flux2electron(diameter, obscure, delta_lambda_per_pixel, spaxel_xsize, spaxe
         return np.nan
 
 
-def electron2flux(config, wavearr, countsarr, throughtputwave, throughtputvalue, fluxunit=''):
+def electron2flux(diameter, obscure, delta_lambda_per_pixel, spaxel_xsize, spaxel_ysize,
+                  wavearr, countsarr, throughtputwave, throughtputvalue, fluxunit=''):
     '''
     :param wavearr: A
     :param countsarr: e-/s
     :return:
     '''
 
-    instru = config['configuration']
 
     cc = 3.0e18   # speed of light, A/s
-    spaxel_area = instru['spaxel_xsize'] * instru['spaxel_ysize']    # arcsec^2
-    d = 200  # diameter of the telescope, in cm unit
-    obscure = 0.0  # effective central obscuration, no unit
-    telarea = 3.14159 / 4.0 * d * d * (1.0 - obscure)  # effective area of the telescope, cm^2
-    delta_lambda_per_pixel = 1.755555  # per pixel
+    spaxel_area = spaxel_xsize * spaxel_ysize       # arcsec^2
+    telarea = 3.14159 / 4.0 * diameter**2 * (1.0 - obscure)  # effective area of the telescope, cm^2
     delta_hz_per_specpixel = delta_lambda_per_pixel / wavearr**2 * cc  # s^-1
     specsampling = 1.0  # 2 pixels
     planckh = 6.626e-27  # erg*s
@@ -147,7 +144,7 @@ def get_nsky(wavearr):
         fluxskypp[ii] = 0.301 / countd
 
     ms_pix_area = 0.074**2      # arcsec
-    spaxel_area = 0.02**2
+    spaxel_area = 0.2**2
     factor = 0.9
 
     fluxskypp = fluxskypp / ms_pix_area * spaxel_area * factor  # e/s/spaxel/spec-elements
@@ -309,7 +306,7 @@ class calculation_snr(object):
         self.mockerror = signal_rate.fluxcube / self.snr
 
         # model image
-        self.img2d = signal_rate.mag2d
+        # self.img2d = signal_rate.mag2d
 
     def save(self, file):
 
@@ -327,7 +324,7 @@ class calculation_snr(object):
         f.create_dataset('mockwave', data=self.mockwave)
         f.create_dataset('mockflux', data=self.mockflux)
         f.create_dataset('mockerror', data=self.mockerror)
-        f.create_dataset('img2d', data=self.img2d)
+        # f.create_dataset('img2d', data=self.img2d)
         f.close()
 
     def plot(self, outfile):
@@ -438,10 +435,10 @@ class calculation_limitmag(object):
                                 (darkc * repn * obst * npixw * specsampling) +
                                 (nsky * repn * obst))
 
-        source_rate = (-coeff_s1 + np.sqrt(coeff_s1 ** 2 - 4 * coeff_s2 * coeff_s0)) / (2 * coeff_s2)
+        self.source_rate = (-coeff_s1 + np.sqrt(coeff_s1 ** 2 - 4 * coeff_s2 * coeff_s0)) / (2 * coeff_s2)
 
         throughtputwave, throughtputvalue = get_throughput(instru['efficiency_file'])
-        flux = electron2flux(config, ccdspec_wave, source_rate,
+        flux = electron2flux(config, ccdspec_wave, self.source_rate,
                              throughtputwave, throughtputvalue,
                              fluxunit='erg/s/cm^2/A')
 
@@ -535,7 +532,7 @@ class calculation_exptime(object):
         self.mockerror = signal_rate.fluxcube / self.snr
 
         # model image
-        self.img2d = signal_rate.mag2d
+        # self.img2d = signal_rate.mag2d
 
 
     def save(self, file):
@@ -554,7 +551,6 @@ class calculation_exptime(object):
         f.create_dataset('mockwave', data=self.mockwave)
         f.create_dataset('mockflux', data=self.mockflux)
         f.create_dataset('mockerror', data=self.mockerror)
-        f.create_dataset('img2d', data=self.img2d)
         f.close()
 
 
