@@ -1,7 +1,7 @@
 import os
 import numpy as np
 
-from .config import get_instrument_config, build_default_scene, build_default_bkg
+from .config import get_instrument_config
 import pdb
 
 path = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
@@ -183,6 +183,7 @@ def build_input_para():
 
     calc['configuration'] = get_instrument_config(readout_xbin=readout_xbin,
                                                   readout_ybin=readout_ybin,
+                                                  readout_noise=readout_noise,
                                                   gain=gain,
                                                   dark=dark)
 
@@ -221,35 +222,38 @@ def build_input_para():
 
 
 
-    # scene
-    scene = []
+
 
     print('#')
     print('# 4. Specify the source: ')
-    print('#     1. import a simulated datacube. [under development.] ')
+    print('#     1. import a simulated datacube. ')
     print('#     2. Define the source (position, shape, spectrum, brightness).')
     source_mode = check_input(input_message='Select one way',
                             input_type=int,
                             input_range=(1, 2),
                             input_default=2)
+    calc['source_mode'] = source_mode
 
     # import the simulated datacube.
     if source_mode == 1:
         print('#')
         print('# 4. Upload a FITS file.')
         tmp = False
+        datacube_file = ''
         while tmp is False:
-            datacube_file = input('Enter the spectrum file: ')
+            datacube_file = input('Enter the cube FITS file: ')
             file_exists = os.path.exists(datacube_file)
             if file_exists:
                 tmp = True
             else:
                 print('Do not found ' + datacube_file + ', retry.')
                 tmp = False
-
+        calc['source'] = {'filename': datacube_file}
 
     # define the source.
     elif source_mode == 2:
+
+        scene = []
         print('#')
         print('# 4. Define the source (position, shape, spectrum, brightness). ')
         n_source = check_input(input_message='How many sources to be considered',
@@ -494,7 +498,7 @@ def build_input_para():
             # append to the scene one-by-one source.
             scene.append(dic)
 
-    calc['source'] = scene
+        calc['source'] = scene
 
 
     # set the background level
