@@ -210,6 +210,8 @@ class SourceCountsRate(source.ModelCube):
         source.ModelCube.__init__(self, config)    # 按config参数生成fluxcube, wavecube
                                                    # 上传的cube也在这一步插值成符合ccdgrid的cube
 
+        source.ModelCube.ConvolvedCube(self)       # 卷积LSF和PSF
+
         instru = config['configuration']
 
         throughtputwave, throughtputvalue = get_throughput(instru['efficiency_file'])
@@ -222,7 +224,7 @@ class SourceCountsRate(source.ModelCube):
                                            throughtputwave, throughtputvalue,
                                            fluxunit='erg/s/cm^2/A')
         self.wavearr = self.wavecube[:, 0, 0]
-
+        
 
 
 class NoiseCounts(object):
@@ -336,6 +338,9 @@ class calculation_snr(object):
 
     def __init__(self, config):
 
+        import ifs_etc
+        self.__version__ = ifs_etc.__version__
+
         signal_rate = SourceCountsRate(config)
 
         counts = NoiseCounts(config, signal_rate)
@@ -348,7 +353,6 @@ class calculation_snr(object):
         self.straynoise = np.sqrt(counts.nstray)
         self.saturate_mask = (self.source > 65535)
 
-
         self.totnoise = np.sqrt(self.darknoise ** 2 + self.readnoise ** 2 +
                                 self.skynoise ** 2 + self.sourcenoise ** 2 +
                                 self.straynoise ** 2)
@@ -375,9 +379,10 @@ class calculation_snr(object):
 
         # model image
         self.img2d = signal_rate.mag2d
+        
+        # pdb.set_trace()
+
 
-        import ifs_etc
-        self.__version__ = ifs_etc.__version__
 
     def save(self, file):
 
@@ -415,13 +420,16 @@ class calculation_snr(object):
         cm_r = plt.cm.get_cmap('jet_r')
 
         ax_recontructed_magmap = plt.subplot2grid((3, 4), (0, 0))
-        im = ax_recontructed_magmap.imshow(self.img2d, origin='low', extent=(0, 30, 0, 30),
-                                           cmap=cm_r, picker=True)
+        im = ax_recontructed_magmap.imshow(self.img2d, origin='lower', extent=(0, 30, 0, 30),
+                                           cmap=cm_r, picker=True, vmax=19)
         ax_recontructed_magmap.set_xlabel('spaxel')
         ax_recontructed_magmap.set_ylabel('spaxel')
         ax_recontructed_magmap.set_title('reconstructed magmap')
         cbar_ax = fig.add_axes([0.25, 0.75, 0.01, 0.2])
-        cbar = plt.colorbar(im, cax=cbar_ax, ticks=np.arange(20, 25, 2), orientation='vertical')
+        vmin = np.floor(np.min(self.img2d))
+        vmax = np.ceil(np.max(self.img2d))
+        vdelta = np.ceil((vmax-vmin)/5*10)/10
+        cbar = plt.colorbar(im, cax=cbar_ax, ticks=np.arange(vmin, vmax, vdelta), orientation='vertical')
         cbar.set_label(r'mag/arcsec$^{2}$', labelpad=-1)
         cbar.ax.tick_params(labelsize=7)
 
@@ -440,14 +448,8 @@ class calculation_snr(object):
         k = 0
         i = 15
         j = 15
-        ax_snr = plt.subplot2grid((3, 3), (k, 1), colspan=2)
+        ax_snr = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
         ax_snr.plot(self.mockwave, self.snr[:, j, i], 'k-')
-        ax_snr.annotate('surface brightness: \n' + '{:4.1f}'.format(self.img2d[j, i]) + r' mag/arcsec$^{2}$',
-                        xy=(0.75, 0.8), xycoords='axes fraction', color='red')
-        ax_snr.annotate('SNR@5000A: \n' + '{:4.1f}'.format(self.snr[ind, j, i]),
-                        xy=(0.75, 0.65), xycoords='axes fraction')
-        ax_snr.annotate('x: ' + str(i) + ', y: ' + str(j),
-                        xy=(0.05, 0.78), xycoords='axes fraction')
         ax_snr.set_ylabel('SNR')
         ax_snr.set_xlabel('wavelength')
 
@@ -460,12 +462,17 @@ class calculation_snr(object):
         ax_noises.legend(loc=1)
         ax_noises.set_ylabel('noise counts (e-)')
 
-        ax_recontructed_spec = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
+        ax_recontructed_spec = plt.subplot2grid((3, 3), (k, 1), colspan=2)
         ax_recontructed_spec.plot(self.mockwave, self.mockflux[:, j, i], 'k-', label='mockflux')
         ax_recontructed_spec.plot(self.mockwave, self.mockerror[:, j, i], 'b-', label='mockerr')
         ax_recontructed_spec.set_ylabel(r'mock flux (erg/s/cm$^2$/A)')
         ax_recontructed_spec.set_xlabel('wavelength')
-
+        ax_recontructed_spec.annotate('surface brightness: \n' + '{:4.1f}'.format(self.img2d[j, i]) + r' mag/arcsec$^{2}$',
+                        xy=(0.75, 0.8), xycoords='axes fraction', color='red')
+        ax_recontructed_spec.annotate('SNR@5000A: \n' + '{:4.1f}'.format(self.snr[ind, j, i]),
+                        xy=(0.75, 0.65), xycoords='axes fraction', color='red')
+        ax_recontructed_spec.annotate('x: ' + str(i) + ', y: ' + str(j),
+                        xy=(0.05, 0.8), xycoords='axes fraction', color='red')
 
         def onpick(event):
 
@@ -483,14 +490,8 @@ class calculation_snr(object):
             k = 0
             i = xind
             j = yind
-            ax_snr = plt.subplot2grid((3, 3), (k, 1), colspan=2)
+            ax_snr = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
             ax_snr.plot(self.mockwave, self.snr[:, j, i], 'k-')
-            ax_snr.annotate('surface brightness: \n' + '{:4.1f}'.format(self.img2d[j, i]) + r' mag/arcsec$^{2}$',
-                            xy=(0.75, 0.8), xycoords='axes fraction', color='red')
-            ax_snr.annotate('SNR@5000A: \n' + '{:4.1f}'.format(self.snr[ind, j, i]),
-                            xy=(0.75, 0.65), xycoords='axes fraction')
-            ax_snr.annotate('x: ' + str(i) + ', y: ' + str(j),
-                            xy=(0.05, 0.78), xycoords='axes fraction')
             ax_snr.set_ylabel('SNR')
             ax_snr.set_xlabel('wavelength')
 
@@ -503,12 +504,18 @@ class calculation_snr(object):
             ax_noises.legend(loc=1)
             ax_noises.set_ylabel('noise counts (e-)')
 
-            ax_recontructed_spec = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
+            ax_recontructed_spec = plt.subplot2grid((3, 3), (k, 1), colspan=2)
             ax_recontructed_spec.plot(self.mockwave, self.mockflux[:, j, i], 'k-', label='mockflux')
             ax_recontructed_spec.plot(self.mockwave, self.mockerror[:, j, i], 'b-', label='mockerr')
             ax_recontructed_spec.set_ylabel(r'mock flux (erg/s/cm$^2$/A)')
             ax_recontructed_spec.set_xlabel('wavelength')
-
+            ax_recontructed_spec.annotate('surface brightness: \n' + '{:4.1f}'.format(self.img2d[j, i]) + r' mag/arcsec$^{2}$',
+                            xy=(0.75, 0.8), xycoords='axes fraction', color='red')
+            ax_recontructed_spec.annotate('SNR@5000A: \n' + '{:4.1f}'.format(self.snr[ind, j, i]),
+                            xy=(0.75, 0.65), xycoords='axes fraction')
+            ax_recontructed_spec.annotate('x: ' + str(i) + ', y: ' + str(j),
+                            xy=(0.05, 0.78), xycoords='axes fraction')
+            
             fig.canvas.draw()
 
 
