@@ -74,7 +74,7 @@ class read_filter(object):
     # filterfile=filterpath+filtersel   # ;fluxfilter: max=1, min=0, no particular unit
     def __init__(self, filterfile=''):
 
-        print('Filter File:', filterfile)
+        # print('Filter File:', filterfile)
 
         band = pd.read_csv(filterfile, sep='\s+', header=None, comment='#')
         self.wave = band[0].values  # A
