@@ -3,7 +3,7 @@ import pandas as pd
 import os
 import astropy.io.fits as fits
 import astropy.units as u
-from scipy.integrate import simps
+from scipy.integrate import simpson as simps
 from einops import repeat, rearrange
 import extinction
 import pdb
@@ -11,7 +11,7 @@ import pdb
 from astropy.modeling.models import Sersic2D, Box2D, Gaussian2D
 
 path = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
-snpp_refdata = os.path.join(path, 'refdata/')
+refdata = os.path.join(path, 'refdata/')
 
 
 class read_template(object):
@@ -64,7 +64,7 @@ class read_template(object):
 
             # If the data is big endian, swap the byte order to make it little endian
             if template_wave.dtype.byteorder == '>':
-                template_wave = template_wave.byteswap().newbyteorder()
+                template_wave = template_wave.byteswap().view(template_wave.byteswap().dtype.newbyteorder())
 
         elif template_filename.endswith('.txt'):
 
@@ -165,19 +165,41 @@ class read_filter(object):
             filter_name:
         """
 
-        filter_file = os.path.join(snpp_refdata, 'normalization', 'filters', filter_name+'.par')
-        band = pd.read_csv(filter_file, sep='\s+', header=None, comment='#')
-        self.wave = band[0].values  # A
-        self.throughput = band[1].values  # vaccum_pass
-        self.wavemin = self.wave[0]
-        self.wavemax = self.wave[-1]
+        filter0, filter1 = filter_name.split('_')
+        if filter0 == 'sdss':
+            filter_file = os.path.join(refdata, 'normalization', 'filters', filter_name+'.par')
+            band = pd.read_csv(filter_file, sep='\s+', header=None, comment='#')
+            self.wave = band[0].values  # A
+            self.throughput = band[1].values  # vaccum_pass, per photon
+            self.wavemin = self.wave[0]
+            self.wavemax = self.wave[-1]
+
+        elif filter0 == 'Johnson':
+            filter_file = os.path.join(refdata, 'normalization', 'filters', filter_name+'.txt')
+            band = pd.read_csv(filter_file, sep='\s+', header=None, comment='#')
+            self.wave = (band[0].values)[::-1] * 10     # A
+            self.throughput = (band[1].values)[::-1]    # no sure per photon, or per energy. (??)
+            self.wavemin = self.wave[0]
+            self.wavemax = self.wave[-1]
+
+        elif filter0 == 'GALEX':
+            filter_file = os.path.join(refdata, 'normalization', 'filters', filter_name+'.par')
+            band = pd.read_csv(filter_file, sep='\s+', header=None, comment='#')
+            self.wave = band[0].values             # A
+            self.throughput = band[1].values       # no sure per photon, or per energy. (??)
+            self.wavemin = self.wave[0]
+            self.wavemax = self.wave[-1]
+
+        else:
+            print('un_recognized filter system.')
+
 
         # find the central wavelength, effective wavelength, and FWHM of the given filter
-        filtermid = (self.wavemax - self.wavemin) * 0.5  # A, central wavelength
+        # filtermid = (self.wavemax - self.wavemin) * 0.5  # A, central wavelength
         dwave = self.wave[1:] - self.wave[:-1]
         self.waveeff = np.nansum(dwave * self.wave[1:] * self.throughput[1:]) / \
                        np.nansum(dwave * self.throughput[1:])
-                                                                            # A, effective wavelength
+        # A, effective wavelength
         rmax = np.max(self.throughput)
         nnn = np.where(self.throughput > 0.5 * rmax)[0]
         self.FWHMmin = self.wave[nnn[0]]      # wave range at FWHM
@@ -219,6 +241,8 @@ def filter_mag(objwave, objflux, filterwave, filterthroughtput, output='mag'):
 
     if output == 'mag':
         mag = -2.5 * np.log10(integrate_flux) - 48.6
+        if integrate_flux < 0:
+            print('Warning: the intergrate_flux less than 0, the return mag will be NaN.')
         return mag
     elif output == 'flux':
         return integrate_flux
@@ -284,14 +308,16 @@ def normalized(template_wave, template_flux, config):
             u0 = (inormalize['value'] * u.erg / u.s / u.cm ** 2 / u.Hz).to(
                 u.erg / u.s / u.cm ** 2 / u.AA, equivalencies=u.spectral_density(normalized_wave * u.AA)
             )
-        elif inormalize['unit'] == 'AB magnitude':
+            u0 = u0.value
+        elif inormalize['unit'] == 'erg/s/cm^2/A':
+            u0 = inormalize['value']
+        elif (inormalize['unit'] == 'AB magnitude') or (inormalize['unit'] == 'AB magnitude/arcsec^2'):
             u0 = (10**((inormalize['value'] + 48.6)/(-2.5)) * u.erg / u.s / u.cm ** 2 / u.Hz).to(
                 u.erg / u.s / u.cm ** 2 / u.AA, equivalencies=u.spectral_density(normalized_wave * u.AA)
             )
+            u0 = u0.value
         else:
-            u0 = inormalize['value']
-
-        u0 = u0.value
+            raise ValueError('Unrecognized unit of the source.')
 
 
         # get scaled 2d image
@@ -389,7 +415,7 @@ class ModelCube(object):
         self.ccdspec_wave = get_wavearr(config)
         self.ccdspec_nw = len(self.ccdspec_wave)
 
-        if config['source_mode'] == 2:
+        if config['source_mode'] == 2:      # 按参数生成的模型
 
             n_source = len(config['source'])
             for i in range(n_source):
@@ -408,7 +434,7 @@ class ModelCube(object):
                 # 不同template并没有起作用。
                 # todo: 把normalized里的循环取消，在这里增加循环，以及流量叠加。
 
-        elif config['source_mode'] == 1:
+        elif config['source_mode'] == 1:    # 冯帅生成的模型作为输入
 
             import astropy.io.fits as fits
             dat = fits.open(config['source']['filename'])
@@ -417,7 +443,7 @@ class ModelCube(object):
             wave_delta = template_hdr['CDELT1'] * 1e10
             wave_end = wave_start + template_hdr['NAXIS1']*wave_delta
             template_wave = np.arange(wave_start, wave_end, wave_delta)
-            template_flux = dat[1].data * 1e-17        # erg/s/cm^/A
+            template_flux = dat[1].data * 1e-17 / 0.04      # erg/s/cm^/A / arcsec^2
             nx = template_hdr['NAXIS2']
             ny = template_hdr['NAXIS3']
 
@@ -426,9 +452,13 @@ class ModelCube(object):
 
             from scipy.interpolate import interp1d
             fluxcube_reshape = rearrange(template_flux, 'h w c -> c h w')
+                                                # c: wavelength, h: dec, w: ra
             fluxcube_interp = wavecube_interp.copy()
             filter = read_filter('sdss_g')
-            mag2d = np.zeros(shape=(ny, nx), dtype=float)
+            mag2d = np.zeros(shape=(ny, nx), dtype=float)  # here is surface brightness
+
+            # pdb.set_trace()
+
             for i in range(nx):
                 for j in range(ny):
                     f = interp1d(wavecube[:, j, i], fluxcube_reshape[:, j, i], fill_value='extrapolate')
@@ -436,6 +466,9 @@ class ModelCube(object):
                     mag2d[j, i] = filter_mag(wavecube_interp[:, j, i], fluxcube_interp[:, j, i],
                                              filter.wave, filter.throughput, output='mag')
 
+                    # if np.isnan(mag2d[j, i]) == True:
+                    #     pdb.set_trace()
+
             self.wavecube = wavecube_interp
             self.fluxcube = fluxcube_interp
             self.mag2d = mag2d
@@ -444,5 +477,39 @@ class ModelCube(object):
     # def export_to_fits(self, fitsfile='ModelCube'):
 
 
-# class ConvolvedCube(object):
+    def ConvolvedCube(self):
+        
+        from astropy.convolution import convolve
+        
+        psf = fits.getdata(refdata+'source/psf_026.fits', 0)
+        lsf = fits.getdata(refdata+'source/lsf_13.fits', 0)
+
+        nw, ny, nx = self.fluxcube.shape
+        flux_conv1 = np.zeros(shape=self.fluxcube.shape, dtype=float)
+        flux_conv2 = np.zeros(shape=self.fluxcube.shape, dtype=float)
+        
+        # psf convolve
+        for i in range(nw):
+            flux_conv1[i, :, :] = convolve(self.fluxcube[i, :, :], psf)
+            
+        # lsf convolve
+        for i in range(nx):
+            for j in range(ny):
+                flux_conv2[:, j, i] = convolve(flux_conv1[:, j, i], lsf)
+        
+        self.fluxcube = flux_conv2
+        
+        # update the magnitude
+        filter = read_filter('sdss_g')
+        mag2d = np.zeros(shape=(ny, nx), dtype=float)
+        for j in range(ny):
+            for i in range(nx):
+                mag2d[j, i] = filter_mag(self.wavecube[:, j, i], self.fluxcube[:, j, i],
+                                    filter.wave, filter.throughput, output='mag')
+        self.mag2d = mag2d
+
+
+        
+           
+        
 
